# [Zope-tests] OK : winbot / ZODB_dev py_270_win32

buildbot at winbot.zope.org buildbot at winbot.zope.org
Tue Feb 1 21:08:42 EST 2011

- Previous message: [Zope-tests] FAILED : Zope 3.4 Known Good Set / py2.4-64bit-linux
- Next message: [Zope-tests] FAILED : ZTK 1.0dev / Python2.4.6 Linux 64bit
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : winbot / ZODB_dev py_270_win32
    Build: http://winbot.zope.org/builders/ZODB_dev%20py_270_win32/builds/196

    Build Reason: The Nightly scheduler named 'ZODB_dev py_270_win32_nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://winbot.zope.org/

- Previous message: [Zope-tests] FAILED : Zope 3.4 Known Good Set / py2.4-64bit-linux
- Next message: [Zope-tests] FAILED : ZTK 1.0dev / Python2.4.6 Linux 64bit
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list